/****************************************************
   TORNADO-E64xx on-board I/O peripherals test.
   Control Registers test. rev.1A
   (C) MicroLAB Systems, 2002


   Description:
   ------------
	This demo scans continuously control registers within
    the DSP environment.


   TORNADO platform:
   -----------------
	This demo does not utilize any host TORNADO resources
	and runs in stand-alone mode. MIRAGE JTAG emulator and
	TI CCS tools are required to recompile this demo and to
	upload code to the on-board DSP environment.

  Copyright:
  ----------
	This demo is distributed free of charge and as it is without
	any obligation from MicroLAB Systems.


  Demo and Signal Parameters:
  ---------------------------
	- on-board BOOTMODE configuration switch: NOBOOT
*****************************************************/
#define	__TE6X_SDRAM128M__
#define	__TE6X_SELECT_E64XX__

#include "c6x_def.h"
#include "te6x_dsp.h"



main()
{ int i;

	// initialize DSP
   TE6X_init_dsp_emif(0);

	// enter infinite test loop
   while(1)
    {
		// use WDT RESET strobe as synchro-pulse if oscilloscope is being used
		TE6X_set_wdt_reset();

		// test WDT enable
        TE6X_set_wdt_enable(ON);
		if(TE6X_get_wdt_enable()!=ON) goto error;
        TE6X_set_wdt_enable(OFF);
		if(TE6X_get_wdt_enable()!=OFF) goto error;

		// test RTC access enable
        TE6X_uset_rtc_access_enable(ON);
		if(TE6X_uget_rtc_access_enable()!=ON) goto error;
        TE6X_uset_rtc_access_enable(OFF);
		if(TE6X_uget_rtc_access_enable()!=OFF) goto error;


		// test PIOX-16/SIOX reset control register
        TE6X_set_px_reset(TE6X_PX_RESET_OFF);
		if(TE6X_get_px_reset()!=TE6X_PX_RESET_OFF) goto error;
        TE6X_set_px_reset(TE6X_PX_RESET_ON);
		if(TE6X_get_px_reset()!=TE6X_PX_RESET_ON) goto error;

        TE6X_set_sxa_reset(TE6X_SXA_RESET_OFF);
		if(TE6X_get_sxa_reset()!=TE6X_SXA_RESET_OFF) goto error;
        TE6X_set_sxa_reset(TE6X_SXA_RESET_ON);
		if(TE6X_get_sxa_reset()!=TE6X_SXA_RESET_ON) goto error;

		// test RESET signal for MXSIOX site
        TE6X_set_sxb_reset(TE6X_SXB_RESET_OFF);
		if(TE6X_get_sxb_reset()!=TE6X_SXB_RESET_OFF) goto error;
       	TE6X_set_sxb_reset(TE6X_SXB_RESET_ON);
		if(TE6X_get_sxb_reset()!=TE6X_SXB_RESET_ON) goto error;


        TE6X_set_pxsx_reset_rg(0);
		if(TE6X_get_pxsx_reset_rg()!=0) goto error;
       	TE6X_set_pxsx_reset_rg(7);
		if(TE6X_get_pxsx_reset_rg()!=7) goto error;
        TE6X_set_pxsx_reset_rg(0);
		if(TE6X_get_pxsx_reset_rg()!=0) goto error;


		// verify read-back bootmode data
		if(!TE64XX_BMODE_IS_NONE) goto error;

		// verify device ID register read-back data
		if(		TE6X_get_dev_id()!=TE6414_DEV_ID
			&&	TE6X_get_dev_id()!=TE6415_DEV_ID
			&&	TE6X_get_dev_id()!=TE6416_DEV_ID
		  )
			goto error;

		// verify device revision ID register read-back data
		if(		TE6X_get_dev_rev_id()!=TE64XX_REV_ID_REV1A
			&&	TE6X_get_dev_rev_id()!=TE64XX_REV_ID_REV1A1
			&&	TE6X_get_dev_rev_id()!=TE64XX_REV_ID_REV1A2
		  )
		  	goto error;

		// test EXT_INT/NMI source selectors
		// !!!note!!!: NMI source selector must not be tested since
		//			   no NMI interrupt handler is provided in this demo

		// ensure that NMI selector is OFF
		TE6X_SET_EXT_INT_SEL_OFF(TE6X_NMI_SEL);
	  	if(!TE6X_EXT_INT_SEL_IS_OFF(TE6X_NMI_SEL)) goto error;

		for(i=0;i<=15;i++)
		{
	          TE6X_set_ext_int6_sel(i);
	          TE6X_set_ext_int7_sel(~i);
	          TE6X_set_ext_int4_sel(i+8);
	          TE6X_set_ext_int5_sel(i+5);

			  if(	TE6X_get_ext_int6_sel()!=i
				 || TE6X_get_ext_int7_sel()!=((~i) &0xf)
				 || TE6X_get_ext_int4_sel()!=((i+8) &0xf)
				 || TE6X_get_ext_int5_sel()!=((i+5) &0xf)
				) 
				goto error;

		}

		TE6X_SET_EXT_INT_SEL_SXIRQ0(TE6X_EXT_INT4_SEL);
	    TE6X_SET_EXT_INT_SEL_SXIRQ1(TE6X_EXT_INT5_SEL);
	    TE6X_SET_EXT_INT_SEL_SXIRQ2(TE6X_EXT_INT6_SEL);
	    TE6X_SET_EXT_INT_SEL_USART(TE6X_EXT_INT7_SEL);
    }

	// get here on any error condition
  error:
    while(1) ;

}



