/****************************************************
   TORNADO-E6x on-board I/O peripherals test.
   Control Registers test. rev.1A
   (C) MicroLAB Systems, 1999-2001


   Description:
   ------------
	This demo scans continuously control registers within
    the DSP environment.


   TORNADO platform:
   -----------------
	This demo does not utilize any host TORNADO resources
	and runs in stand-alone mode. MIRAGE JTAG emulator and
	TI CCS tools are required to recompile this demo and to
	upload code to the on-board DSP environment.

  Copyright:
  ----------
	This demo is distributed free of charge and as it is without
	any obligation from MicroLAB Systems.


  Demo and Signal Parameters:
  ---------------------------
        on-board BOOTMODE configuration switch:
	  - MAP0/NOBOOT/SBSRAM
*****************************************************/

#include "c6x_def.h"
#include "te6x_dsp.h"



main()
{ int i;

	// configure DSP on-chip EMIF registers for operation with SBSRAM in CE-0 area
   TE6X_init_dsp_emif(TE6X_XMEM_SBSRAM);


	// enter infinite test loop
   while(1)
    {
		// use WDT RESET strobe as synchro-pulse if oscilloscope is being used
		TE6X_set_wdt_reset();

		// test WDT enable register
        TE6X_set_wdt_enable(ON);
		if(TE6X_get_wdt_enable()!=ON) goto error;
        TE6X_set_wdt_enable(OFF);
		if(TE6X_get_wdt_enable()!=OFF) goto error;


		// test PIOX-16/SIOX reset control register
        TE6X_set_px_reset(TE6X_PX_RESET_OFF);
		if(TE6X_get_px_reset()!=TE6X_PX_RESET_OFF) goto error;
        TE6X_set_px_reset(TE6X_PX_RESET_ON);
		if(TE6X_get_px_reset()!=TE6X_PX_RESET_ON) goto error;

        TE6X_set_sxa_reset(TE6X_SXA_RESET_OFF);
		if(TE6X_get_sxa_reset()!=TE6X_SXA_RESET_OFF) goto error;
        TE6X_set_sxa_reset(TE6X_SXA_RESET_ON);
		if(TE6X_get_sxa_reset()!=TE6X_SXA_RESET_ON) goto error;

			// test RESET signal for MXSIOX site for E6202/E6203 boards
		if(TE6202_BOARD || TE6203_BOARD)
		{
	        TE6X_set_sxb_reset(TE6X_SXB_RESET_OFF);
			if(TE6X_get_sxb_reset()!=TE6X_SXB_RESET_OFF) goto error;
        	TE6X_set_sxb_reset(TE6X_SXB_RESET_ON);
			if(TE6X_get_sxb_reset()!=TE6X_SXB_RESET_ON) goto error;
		}


        TE6X_set_pxsx_reset_rg(0);
		if(TE6X_get_pxsx_reset_rg()!=0) goto error;
       	TE6X_set_pxsx_reset_rg(7);
		if(		TE62_TE67_BOARD && TE6X_get_pxsx_reset_rg()!=3
			||	TE6202_TE6203_BOARD && TE6X_get_pxsx_reset_rg()!=7
		  ) 
			goto error;
        TE6X_set_pxsx_reset_rg(0);
		if(TE6X_get_pxsx_reset_rg()!=0) goto error;



		if( TE6202_TE6203_BOARD)
		{
			// verify read-back bootmode data for TE6202/TE6203
			if(!TE6X_BMODE_IS_MAP0_NONE_SBSRAM) goto error;

			// test XMEM_CNTR register for E6202/E6203
			// !!!note!!!: this must ensure that program/data code has been allocated to
			//             DSP on-chip memory
	        TE6X_SET_XMEM_SBSRAM;
			if(!TE6X_XMEM_IS_SBSRAM) goto error;
        	TE6X_SET_XMEM_SDRAM;
			if(!TE6X_XMEM_IS_SDRAM) goto error;
    	    TE6X_SET_XMEM_SBSRAM;
			if(!TE6X_XMEM_IS_SBSRAM) goto error;
		}



		// test EXT_INT source selectors
		// !!!note!!!: NMI source selector for E6202/E6203 shall not be tested since
		//			   no NMI interrupt handler is provided in this demo

		if(TE62_TE67_BOARD)
		{
			// for E62/E67 test EXT_INT6/EXT_INT7 selectors only
	       for(i=0;i<=3;i++)
			{
	          TE6X_set_ext_int6_sel(i);
			  if(TE6X_get_ext_int6_sel()!=i) goto error;

	          TE6X_set_ext_int7_sel(3-i);
			  if(TE6X_get_ext_int7_sel()!=(3-i)) goto error;
			}

	       TE6X_set_ext_int6_sel(TE6X_EXT_INT_SEL_XIRQ2);
    	   TE6X_set_ext_int7_sel(TE6X_EXT_INT_SEL_USART);
		}
		else
		{
			// for E6202/E6203 test EXT_INT4..7 selectors

				// ensure that NMI selector is OFF
          TE6X_SET_EXT_INT_SEL_OFF(TE6X_NMI_SEL);
		  if(!TE6X_EXT_INT_SEL_IS_OFF(TE6X_NMI_SEL)) goto error;

	       for(i=0;i<=15;i++)
			{
	          TE6X_set_ext_int6_sel(i);
	          TE6X_set_ext_int7_sel(~i);
	          TE6X_set_ext_int4_sel(i+8);
	          TE6X_set_ext_int5_sel(i+5);

			  if(	TE6X_get_ext_int6_sel()!=i
				 || TE6X_get_ext_int7_sel()!=((~i) &0xf)
				 || TE6X_get_ext_int4_sel()!=((i+8) &0xf)
				 || TE6X_get_ext_int5_sel()!=((i+5) &0xf)
				) 
				goto error;

			}

	       TE6X_SET_EXT_INT_SEL_SXIRQ0(TE6X_EXT_INT4_SEL);
	       TE6X_SET_EXT_INT_SEL_SXIRQ1(TE6X_EXT_INT5_SEL);
	       TE6X_SET_EXT_INT_SEL_SXIRQ2(TE6X_EXT_INT6_SEL);
	       TE6X_SET_EXT_INT_SEL_USART(TE6X_EXT_INT7_SEL);
		}
    }

	// get here on any error condition
  error:
    while(1) ;

}



