/********************************************************************
   TORNADO-E6x DCM Demo Utility.
   Test for Bootload from FLASH with DRAM test and USART channel-A commuication. rev.1A
   (C) MicroLAB Systems, 2000


   Description:
   ------------
	This demo boots from FLASH/EPROM to DSP on-chip memory and afterthat 
	continuously tests SBSRAM at addresses 0x2000..0x1ffff and displays test 
	results via USART channel-A, which must be configured in ASYNC mode 9600 bauds 
	with RS232C external interface. 

	External 9600 baud ASYNC terminal with RS232C interface or 
	PC COM port running in terminal mode at 9600 bauds shall be 
	used with this demo.


   TORNADO platform:
   -----------------
	TI CCS tools are required to recompile this demo and to
	upload code to the on-board DSP environment.

  Copyright:
  ----------
	This demo is distributed free of charge and as it is without
	any obligation from MicroLAB Systems.


  board configuration and demo parameters:
  ----------------------------------------
    on-board configuration switch SW2:
	  - MAP0/FLASH8/SBSRAM BOOT mode

	on-board SW4 switch:
	  - RS232C I/F must be used as external I/F for USART channel-A

	on-board socket S5:
	  - 1.8432 MHz crystal oscillator must be used as USART
	    source/master clock
***********************************************************************/


#define	ML_OFF			0
#define	ML_ON			1

#include	<string.h>
#include "c6x_def.h"
#include "te6x_dsp.h"


char welcome[]	= "E6x Bootloader/UART-A test:  ";
char ok_mess[]	= " OK-";
char err_mess[]	= " ERROR ";


usart_a_init()
{
	//configure all pins as outputs
	TE6X_set_usart_rg(TE_USART_CH_A+TE_USART_PCR_RG,0);  

	// now configure USART channel-A in ASYNC mode with 9600 baud rate
	TE6X_set_usart_rg(TE_USART_CH_A+TE_USART_CCR0_RG,0);
	TE6X_set_usart_rg(TE_USART_CH_A+TE_USART_MODE_RG,0);
	TE6X_set_usart_rg(TE_USART_CH_A+TE_USART_CCR0_RG,0x43);		// MCE, ASYNC
	TE6X_set_usart_rg(TE_USART_CH_A+TE_USART_CCR1_RG,0x1f); 	// ODS, BCR, clk_mode=7
	TE6X_set_usart_rg(TE_USART_CH_A+TE_USART_CCR2_RG,0x38);		// BDF, SSEL (clk_mode=7b), TCLK = out
	TE6X_set_usart_rg(TE_USART_CH_A+TE_USART_DAFO_RG,0x00); 	// STOP=1, PARity=OFF, 8bit
	TE6X_set_usart_rg(TE_USART_CH_A+TE_USART_RFC_RG, 0x00);		// RFIFO threshold = 1
    TE6X_set_usart_rg(TE_USART_CH_A+TE_USART_BGR_RG, 0x05);		// 9600 bauds

    TE6X_set_usart_rg(TE_USART_CH_A+TE_USART_CCR0_RG, 
					  TE6X_usart_rg(TE_USART_CH_A+TE_USART_CCR0_RG) | 0x80);	// PU: set channel activity
	TE6X_set_usart_rg(TE_USART_CH_A+TE_USART_CMDR_RG,0x41);		// receiver/transmitter reset
	TE6X_set_usart_rg(TE_USART_CH_A+TE_USART_MODE_RG,0x0c);		// receiver active, set RTS

	TE6X_set_usart_rg(TE_USART_CH_A+TE_USART_IPC_RG, 0x81);		// set unmasked irqs visible, irq active low
	TE6X_set_usart_rg(TE_USART_CH_A+TE_USART_GIS_RG, 0x08);		// enable IRQS from IRQ1/USART-A
	TE6X_set_usart_rg(TE_USART_CH_A+TE_USART_IMR1_RG,~0x21);	// enable IRQS from ALLS/XPR
}

#define WAIT_CMDR_READY   {while (TE6X_usart_rg(TE_USART_CH_A+TE_USART_STAR_RG) &0x4);}

uart_transmit_char(c)
int c;
{
	// transmit using XPR irq with bits ALLS/XPR from ISR1 
  while (!(TE6X_get_usart_rg(TE_USART_CH_A+TE_USART_ISR1_RG) &0x21));
  TE6X_set_usart_rg(TE_USART_CH_A+TE_USART_TFIFO_RG,c);
  WAIT_CMDR_READY;
  TE6X_set_usart_rg(TE_USART_CH_A+TE_USART_CMDR_RG,0x8);
}


int uart_receive_char()
{ int c;

  while (!(TE6X_usart_rg(TE_USART_CH_A+TE_USART_STAR_RG) &0x20));
  c= TE6X_usart_rg(TE_USART_CH_A+TE_USART_RFIFO_RG) & 0xff;
  WAIT_CMDR_READY;
  TE6X_set_usart_rg(TE_USART_CH_A+TE_USART_CMDR_RG,0x80);	// release RFIFO
  return(c);
}


int uart_receiver_status()
{
  return((TE6X_usart_rg(TE_USART_CH_A+TE_USART_STAR_RG) & 0x20) ? 1:0);
}


uart_transmit_mess(s)
char *s;
{
  while((*s &0xff)!=0) uart_transmit_char(*(s++));
}





#define ML_OK		0
#define ML_MEM_ERR	-1



int next_cell(i)
{
  return( (((~i ^ 0x93a5 -1) <<8)  & 0xff00)
		 |(((~i ^ 0xe479 +1) <<16) & 0xff0000)
		 |(((~i ^ 0xc653 +1) <<24) & 0xff000000)
		 |((i+1) & 0xff)  
	    );
}



int mem_test(init_value, sa, ea)
int init_value, *sa, *ea;

{ int r;
  int *ptr,i;

	r=ML_MEM_ERR;

    for(i=init_value,ptr=sa; ptr<=ea; ptr++)
	  { *ptr=i;
	    i=next_cell(i);
	  } ;
    for(i=init_value,ptr=sa; ptr<=ea; ptr++)
	  { if (*ptr !=i) return (r);
	    i=next_cell(i);
	  }
    return(ML_OK);
}


void report_ok_n(int n)
{ char s[8],*c;

  strcpy(s,ok_mess);
  c=&(s[strlen(s)]);
  *c='0'+(n%10);
  *++c=0;
  uart_transmit_mess(s);

}




void main()
{
	int pass_counter;
	int iv, *start, *end;

	// configure DSP EMIF
	TE6X_init_dsp_emif(TE6X_XMEM_SBSRAM);

	// configure USART
	usart_a_init();


    uart_transmit_mess(welcome);


	start	= (int *)0x00002000;
	end	= (int *)0x0001fff8;

    iv = 0x3e91df48;
	pass_counter=0;

    while (1)
	 {
		switch(mem_test(iv,start,end))
		  {
		    case ML_OK:
		        report_ok_n(pass_counter);
			break;

		    default:
		        uart_transmit_mess(err_mess);
				goto end;
		  }


		iv =    ( (((iv+1)^0x935f) <<16)
			 |(((iv-1)^0xa75a) & 0xffff)  );

	    pass_counter++;
		pass_counter %=10;
	 }


end:
	;

}



