/********************************************************************
   TORNADO-E64xx Demo Utility.
   PIOX IRQ test. rev.1A
   (C) MicroLAB Systems, 2002


   Description:
   ------------
	This demo tests PIOX interrupt requests (PXIRQs) for E64xx.
	PXIRQs for E64xx comprise of PIOX interrupt requests (PX_IRQ-0..3).

	User can apply external	PIOX interrupt request from signal generator, 
	etc sources	and observe DSP response via USART PIO-0..3 I/O pins at JP10
	on-board edge connector, which are configued as the OUTPUTS. PIO-0..3 
	outputs can be observed via oscilloscope.

	PIOX interrupt request selectors for C64xx DSP and the 
	corresponding USART PIO output pins, which are used to display
	respond of DSP to each of external interrupts, are set as 
	following:
		IRQ source:	DSP IRQ:	USART PIO output:
		-----------	--------	-----------------
		PXIRQ-0		EXT_INT4		PIO-0
		PXIRQ-1		EXT_INT5		PIO-1
		PXIRQ-2		EXT_INT6		PIO-2
		PXIRQ-3		EXT_INT7		PIO-3

	
		Note!!!:
		--------
			1. This test does not run at E620x/E670x boards. Use E6X_SXIRQ.* test 
			   for testing PIOX IRQs at E62/E67 and E6X_PXIRQ.* test for E6202/E6203
			   boards.

			2. This test does not perform testing of USART and USB
			   interrupt requests. Use UUIRQ.* test for testing USB/USART IRQs.

   TORNADO platform:
   -----------------
	MIRAGE JTAG emulator and TI C6000 CCS v.2 tools are required to 
	recompile this demo and to upload code to the on-board DSP 
	environment.

  Copyright:
  ----------
	This demo is distributed free of charge and as it is without
	any obligation from MicroLAB Systems.


  board configuration and demo parameters:
  ----------------------------------------
	- on-board configuration switch: NOBOOT
***********************************************************************/

#define	__TE6X_SDRAM128M__
#define	__TE6X_SELECT_E64XX__


#include "c6x_def.h"
#include "te6x_dsp.h"



#pragma NMI_INTERRUPT(nmi_isr)
// NMI ISR must toggle USART PIO-4 pin.
// NMI ISR must be disabled in this test.
void nmi_isr(void)
{
	TE6X_set_usart_rg(TE_USART_PVR_RG,
			   		  TE6X_get_usart_rg(TE_USART_PVR_RG) ^ 0x10
					 ); 
}


// EXT_INT4 ISR must toggle USART PIO-0 pin
interrupt void xint4_isr(void)  
{
	TE6X_set_usart_rg(TE_USART_PVR_RG,
			   		  TE6X_get_usart_rg(TE_USART_PVR_RG) ^ 0x1
					 ); 
}


// EXT_INT5 ISR must toggle USART PIO-1 pin
interrupt void xint5_isr(void)  
{
	TE6X_set_usart_rg(TE_USART_PVR_RG,
			   		  TE6X_get_usart_rg(TE_USART_PVR_RG) ^ 0x2
					 ); 
}


// EXT_INT6 ISR must toggle USART PIO-2 pin
interrupt void xint6_isr(void)  
{
	TE6X_set_usart_rg(TE_USART_PVR_RG,
			   		  TE6X_get_usart_rg(TE_USART_PVR_RG) ^ 0x4
					 ); 
}


// EXT_INT7 ISR must toggle USART PIO-3 pin.
interrupt void xint7_isr(void)  
{
	TE6X_set_usart_rg(TE_USART_PVR_RG,
			   		  TE6X_get_usart_rg(TE_USART_PVR_RG) ^ 0x8
					 ); 
}




main()
{
	// initialize DSP
	TE6X_init_dsp_emif(0);

	// perform this test for E64xx boards only
	if(TE64XX_BOARD)
	{

		// configure EXT_INT polarity upon the E6x board type
		TE6X_INIT_EXT_INT_POLARITY;

		// configure USART PIO port as outputs and clear outputs
		TE6X_set_usart_rg(TE_USART_PCR_RG,0);
		TE6X_set_usart_rg(TE_USART_PVR_RG,0);

		// configure EXT_INT4..7 IRQ source selectors to use PXIRQ0..3 IRQ sources.
		TE6X_SET_EXT_INT_SEL_OFF(TE6X_NMI_SEL);			// disable NMI for E64xx
		TE6X_SET_EXT_INT_SEL_PXIRQ0(TE6X_EXT_INT4_SEL);	// configure EXT_INT4 to PXIRQ0
		TE6X_SET_EXT_INT_SEL_PXIRQ1(TE6X_EXT_INT5_SEL);	// configure EXT_INT5 to PXIRQ1
		TE6X_SET_EXT_INT_SEL_PXIRQ2(TE6X_EXT_INT6_SEL);	// configure EXT_INT6 to PXIRQ2
		TE6X_SET_EXT_INT_SEL_PXIRQ3(TE6X_EXT_INT7_SEL);	// configure EXT_INT7 to PXIRQ3

		C6X_INT_ENABLE(4);  // enable EXT_INT4..7
   		C6X_INT_ENABLE(5);
	   	C6X_INT_ENABLE(6);
   		C6X_INT_ENABLE(7);

	   	C6X_INT_CLEAR_ALL;
   		C6X_GINT_ENABLE;    /* set GIE bit */


	   while(1)
    	{
    	}
	}

}


