/********************************************************************
   TORNADO-E6x Demo Utility.
   SIOX IRQ test. rev.1A
   (C) MicroLAB Systems, 2000


   Description:
   ------------
	This demo tests SIOX interrupt requests (SXIRQs). SXIRQs for
	E6x comprise of SIOX-A/B interrupt requests (SX_IRQ-0/1/2), which
	are also common for PIOX interrupt requests for E62/E67.

	User can apply external	SIOX interrupt request from signal generator, 
	etc sources	and observe DSP response via USART PIO-0..2 I/O pins at JP10
	on-board edge connector, which are configued as the OUTPUTS. PIO-0..2 
	outputs can be observed via oscilloscope.

	SIOX interrupt request selectors for C6x DSP and the 
	corresponding USART PIO output pins, which are used to display
	respond of DSP to each of external interrupts, are set as 
	following:
		IRQ source:	DSP IRQ:	USART PIO output:
		-----------	--------	-----------------
		SXIRQ-0		EXT_INT4		PIO-0
		SXIRQ-1		EXT_INT5		PIO-1
		SXIRQ-2		EXT_INT6		PIO-2

	
		Note!!!:
		--------
			1. This test does not provide PIOX IRQs (PXIRQ0..3) test for
			   E6202/E6203. Use PXIRQ.* test for testing PIOX IRQs.

			2. This test does not perform testing of USART and USB
			   interrupt requests. Use UUIRQ.* test for testing USB/USART IRQs.

   TORNADO platform:
   -----------------
	MIRAGE JTAG emulator and TI C6000 CCS v.2 tools are required to 
	recompile this demo and to upload code to the on-board DSP 
	environment.

  Copyright:
  ----------
	This demo is distributed free of charge and as it is without
	any obligation from MicroLAB Systems.


  board configuration and demo parameters:
  ----------------------------------------
        on-board configuration switch SW2:
	  - MAP0/NOBOOT/SBSRAM bootmode
***********************************************************************/


#include "c6x_def.h"
#include "te6x_dsp.h"



#pragma NMI_INTERRUPT(nmi_isr)
// NMI ISR must toggle USART PIO-4 pin.
// NMI ISR must be disabled in this test.
void nmi_isr(void)
{
	TE6X_set_usart_rg(TE_USART_PVR_RG,
			   		  TE6X_get_usart_rg(TE_USART_PVR_RG) ^ 0x10
					 ); 
}


// EXT_INT4 ISR must toggle USART PIO-0 pin
interrupt void xint4_isr(void)  
{
	TE6X_set_usart_rg(TE_USART_PVR_RG,
			   		  TE6X_get_usart_rg(TE_USART_PVR_RG) ^ 0x1
					 ); 
}


// EXT_INT5 ISR must toggle USART PIO-1 pin
interrupt void xint5_isr(void)  
{
	TE6X_set_usart_rg(TE_USART_PVR_RG,
			   		  TE6X_get_usart_rg(TE_USART_PVR_RG) ^ 0x2
					 ); 
}


// EXT_INT6 ISR must toggle USART PIO-2 pin
interrupt void xint6_isr(void)  
{
	TE6X_set_usart_rg(TE_USART_PVR_RG,
			   		  TE6X_get_usart_rg(TE_USART_PVR_RG) ^ 0x4
					 ); 
}


// EXT_INT7 ISR must toggle USART PIO-3 pin.
// EXT_INT7 ISR must be disabled in this test.
interrupt void xint7_isr(void)  
{
	TE6X_set_usart_rg(TE_USART_PVR_RG,
			   		  TE6X_get_usart_rg(TE_USART_PVR_RG) ^ 0x8
					 ); 
}




main()
{
	// init DSP EMIF areas for using SBSRAM in CE-0 
	TE6X_init_dsp_emif(TE6X_XMEM_SBSRAM);

	// configure EXT_INT polarity upon the E6x board type
	TE6X_INIT_EXT_INT_POLARITY;

	// configure USART PIO port as outputs and clear outputs
	TE6X_set_usart_rg(TE_USART_PCR_RG,0);
	TE6X_set_usart_rg(TE_USART_PVR_RG,0);

	// configure EXT_INT4..6 IRQ source selectors to use SXIRQ0..2 IRQ sources.
	// notes: 
	//		1. for E62/E67 only EXT_INT6 selector have to be configured to SXIRQ2.
	//		2. for E6202/E6203 EXT_INT4..5 selectors have to be configured to
	//		   SXIRQ0..1 and NMI selector have to be disabled.
	if(TE6202_TE6203_BOARD)
	{
		TE6X_SET_EXT_INT_SEL_OFF(TE6X_NMI_SEL);			// disable NMI for E6202/E6203
		TE6X_SET_EXT_INT_SEL_SXIRQ0(TE6X_EXT_INT4_SEL);	// configure EXT_INT4 to SXIRQ0 for E6202/E6203
		TE6X_SET_EXT_INT_SEL_SXIRQ1(TE6X_EXT_INT5_SEL);	// configure EXT_INT5 to SXIRQ1 for E6202/E6203
	}

	TE6X_SET_EXT_INT_SEL_SXIRQ2(TE6X_EXT_INT6_SEL);	// configure EXT_INT6 to SXIRQ2
	TE6X_SET_EXT_INT_SEL_OFF(TE6X_EXT_INT7_SEL);	// disable EXT_INT7


	C6X_INT_ENABLE(4);  // enable EXT_INT4..6
   	C6X_INT_ENABLE(5);
   	C6X_INT_ENABLE(6);
   	C6X_INT_DISABLE(7); // disable EXT_INT7

   	C6X_INT_CLEAR_ALL;
   	C6X_GINT_ENABLE;    /* set GIE bit */


   while(1)
    {
    }

}


