/****************************************************
   TORNADO-E64xx Demo Utility. McBSP-0/1/2 ports test. rev.1A
   (C) MicroLAB Systems, 2002


   Description:
   ------------
	This demo tests DSP McBSP-0/1/2 ports. 

	External DX-to-DR shorting jumpers are equired for each of the
	McBSP-0/1/2 ports in order to run this demo. These shorting 
	jumpers shall be connected to SIOX-A rev.B site (McBSP-0/1 ports)
	and SIO-0 port of MXSIOX site (McBSP-2 port). Refer to TORNADO-E64xx 
	User's Guide for more details about SIOX site headers.

	This test configures all McBSP pins as OUTPUT pins except for
	DR pin, which is configured as INPUT, and continuously generates 
	'running '1'' over DX/DR, FSX, FSR, CLKX and CLKR pins
	for each McBSP port. Oscilloscope can be used to view pulses at
	pins of McBSP-0/1/2 ports.


   TORNADO platform:
   -----------------
	This demo does not utilize any host TORNADO resources
	and runs in stand-alone mode. MIRAGE JTAG emulator and
	TI CCS tools are required to recompile this demo and to
	upload code to the on-board DSP environment.


   Note:
   ------
	This test does not run for E620x/E670x boards. 
	Use E6X_MCBSP.* test instead.


  Copyright:
  ----------
	This demo is distributed free of charge and as it is without
	any obligation from MicroLAB Systems.


  board configuration and demo parameters:
  ----------------------------------------
	- on-board bomode configuration switch: NOBOOT
	- demo-specific jumpers for McBSP ports:
	  - DX-to-DR shorting jumpers are equired for each of the
	    McBSP-0/1/2 ports, which shall be connected to SIOX-A 
	    rev.B site (McBSP-0/1 ports) and SIO-0 site of MXSIOX
		site (McBSP-2 port). 



*****************************************************/
#define	__TE6X_SDRAM128M__
#define	__TE6X_SELECT_E64XX__


#include "c6x_def.h"
#include "te6x_dsp.h"



#define DX_OUT_0      0x3f00
#define DX_OUT_1      0x3f20
#define FSX_OUT_0     0x3f00
#define FSX_OUT_1     0x3f08
#define FSR_OUT_0     0x3f00
#define FSR_OUT_1     0x3f04
#define CLKX_OUT_0    0x3f00
#define CLKX_OUT_1    0x3f02
#define CLKR_OUT_0    0x3f00
#define CLKR_OUT_1    0x3f01

#define DR_BIT_MASK   0x10
#define CLKS_BIT_MASK 0x40
#define CLKR_BIT_MASK 0x1
#define CLKX_BIT_MASK 0x2
#define FSX_BIT_MASK  0x8
#define FSR_BIT_MASK  0x4


unsigned pass_counter=0;

main()
{
   TE6X_init_dsp_emif(0);

   *C6X_MCBSP0_SPCR = 0;   /* configure McBSP-0 for I/O pins */
   *C6X_MCBSP1_SPCR = 0;   /* configure McBSP-1 for I/O pins */
   *C6X_MCBSP2_SPCR = 0;   /* configure McBSP-2 for I/O pins */

   while(1)
    {
		// verify for McBSP-0
		// set DX=1 
      *C6X_MCBSP0_PCR = DX_OUT_1;
      if((*C6X_MCBSP0_PCR & DR_BIT_MASK  ) ==0) break; 
      if((*C6X_MCBSP0_PCR & CLKS_BIT_MASK) ==0) break; 

		// set DX=0
      *C6X_MCBSP0_PCR = DX_OUT_0;
      if((*C6X_MCBSP0_PCR & DR_BIT_MASK  ) !=0) break; 
      if((*C6X_MCBSP0_PCR & CLKS_BIT_MASK) !=0) break; 

      *C6X_MCBSP0_PCR = FSX_OUT_1;
      *C6X_MCBSP0_PCR = FSX_OUT_0;

      *C6X_MCBSP0_PCR = FSR_OUT_1;
      *C6X_MCBSP0_PCR = FSR_OUT_0;

      *C6X_MCBSP0_PCR = CLKX_OUT_1;
      *C6X_MCBSP0_PCR = CLKX_OUT_0;

      *C6X_MCBSP0_PCR = CLKR_OUT_1;
      *C6X_MCBSP0_PCR = CLKR_OUT_0;


		// verify for McBSP-1
		// set DX=1
      *C6X_MCBSP1_PCR = DX_OUT_1;
      if((*C6X_MCBSP1_PCR & DR_BIT_MASK  ) ==0) break; 
      if((*C6X_MCBSP1_PCR & CLKS_BIT_MASK) ==0) break; 

		// set DX=0
      *C6X_MCBSP1_PCR = DX_OUT_0;
      if((*C6X_MCBSP1_PCR & DR_BIT_MASK  ) !=0) break; 
      if((*C6X_MCBSP1_PCR & CLKS_BIT_MASK) !=0) break; 

      *C6X_MCBSP1_PCR = FSX_OUT_1;
      *C6X_MCBSP1_PCR = FSX_OUT_0;

      *C6X_MCBSP1_PCR = FSR_OUT_1;
      *C6X_MCBSP1_PCR = FSR_OUT_0;

      *C6X_MCBSP1_PCR = CLKX_OUT_1;
      *C6X_MCBSP1_PCR = CLKX_OUT_0;

      *C6X_MCBSP1_PCR = CLKR_OUT_1;
      *C6X_MCBSP1_PCR = CLKR_OUT_0;


		// verify for McBSP-2
		// set DX=1
	  *C6X_MCBSP2_PCR = DX_OUT_1;
      if((*C6X_MCBSP2_PCR & DR_BIT_MASK  ) ==0) break; 
	  if((*C6X_MCBSP2_PCR & CLKS_BIT_MASK) ==0) break; 

		// set DX=0
      *C6X_MCBSP2_PCR = DX_OUT_0;
   	  if((*C6X_MCBSP2_PCR & DR_BIT_MASK  ) !=0) break; 
      if((*C6X_MCBSP2_PCR & CLKS_BIT_MASK) !=0) break; 

      *C6X_MCBSP2_PCR = FSX_OUT_1;
   	  *C6X_MCBSP2_PCR = FSX_OUT_0;

      *C6X_MCBSP2_PCR = FSR_OUT_1;
   	  *C6X_MCBSP2_PCR = FSR_OUT_0;

      *C6X_MCBSP2_PCR = CLKX_OUT_1;
   	  *C6X_MCBSP2_PCR = CLKX_OUT_0;

      *C6X_MCBSP2_PCR = CLKR_OUT_1;
   	  *C6X_MCBSP2_PCR = CLKR_OUT_0;


     pass_counter++;
    }

	// get here on any error condition
  error:
    while(1) ;

}



