/********************************************************************
   TORNADO-E6x Demo Utility.
   USART channel-B test in ASYNC mode. rev.1A
   (C) MicroLAB Systems, 2000


   Description:
   ------------
	This demo tests channel-A of USART in ASYNC mode with RS232C
	external interface. 

	External 9600 baud ASYNC terminal with RS232C interface or 
	PC COM port running in terminal mode at 9600 bauds shall be 
	used with this demo.

	After transmission of greeting message to external terminal,
	demo enters echo mode, which performs transmission of 
	received character back to terminal.


   TORNADO platform:
   -----------------
	This demo does not utilize any host TORNADO resources
	and runs in stand-alone mode. MIRAGE JTAG emulator and
	TI CCS tools are required to recompile this demo and to
	upload code to the on-board DSP environment.

  Copyright:
  ----------
	This demo is distributed free of charge and as it is without
	any obligation from MicroLAB Systems.


  board configuration and demo parameters:
  ----------------------------------------
    on-board bootmode configuration switch SW2:
	  - MAP0/NOBOOT/SBSRAM

	on-board SW4 switch:
	  - RS232C I/F must be used as external I/F for USART channel-B
	on-board socket S5:
	  - 1.8432 MHz crystal oscillator must be used as USART
	    source/master clock
***********************************************************************/

#define	ML_OFF			0
#define	ML_ON			1

#include "c6x_def.h"
#include "te6x_dsp.h"

char welcome[]	= "Welcome to E6x USART-B \n\n>>";
char cts_low[]	= "<< RTS: CTS=LOW >>";
char cts_high[]	= "<< RTS: CTS=HIGH >>";
char dsr_low[]	= "<< DTR: DSR=LOW >>";
char dsr_high[]	= "<< DTR: DSR=HIGH >>";


usart_b_init()
{
	//configure all pins as outputs
	TE6X_set_usart_rg(TE_USART_CH_B+TE_USART_PCR_RG,0);  

	// now configure USART channel-B in ASYNC mode with 9600 baud rate
	TE6X_set_usart_rg(TE_USART_CH_B+TE_USART_CCR0_RG,0);
	TE6X_set_usart_rg(TE_USART_CH_B+TE_USART_MODE_RG,0);
	TE6X_set_usart_rg(TE_USART_CH_B+TE_USART_CCR0_RG,0x43);	// MCE, ASYNC
	TE6X_set_usart_rg(TE_USART_CH_B+TE_USART_CCR1_RG,0x1f); 	// ODS, BCR, clk_mode=7
	TE6X_set_usart_rg(TE_USART_CH_B+TE_USART_CCR2_RG,0x38);	// BDF, SSEL (clk_mode=7b), TCLK = out
	TE6X_set_usart_rg(TE_USART_CH_B+TE_USART_DAFO_RG,0x00); 	// STOP=1, PARity=OFF, 8bit
	TE6X_set_usart_rg(TE_USART_CH_B+TE_USART_RFC_RG, 0x00);	// RFIFO threshold = 1
    TE6X_set_usart_rg(TE_USART_CH_B+TE_USART_BGR_RG, 0x05);	// 9600 bauds

    TE6X_set_usart_rg(TE_USART_CH_B+TE_USART_CCR0_RG, 
					  TE6X_usart_rg(TE_USART_CH_B+TE_USART_CCR0_RG) | 0x80);	// PU: set channel activity

	TE6X_set_usart_rg(TE_USART_CH_B+TE_USART_CMDR_RG,0x41);	// receiver/transmitter reset
	TE6X_set_usart_rg(TE_USART_CH_B+TE_USART_MODE_RG,0x0c);	// receiver active, set RTS

	TE6X_set_usart_rg(TE_USART_CH_B+TE_USART_IPC_RG, 0x81);	// set unmasked irqs visible, irq active low
	TE6X_set_usart_rg(TE_USART_CH_B+TE_USART_GIS_RG, 0x02);	// enable IRQS from IRQ1/USART-b
	TE6X_set_usart_rg(TE_USART_CH_B+TE_USART_IMR1_RG,~0x21);// enable IRQS from ALLS/XPR
}

#define WAIT_CMDR_READY   {while (TE6X_usart_rg(TE_USART_CH_B+TE_USART_STAR_RG) &0x4);}


uart_transmit_char(c)
int c;
{
	// transmit using XPR irq with bits ALLS/XPR from ISR1 
  while (!(TE6X_get_usart_rg(TE_USART_CH_B+TE_USART_ISR1_RG) &0x21));
  TE6X_set_usart_rg(TE_USART_CH_B+TE_USART_TFIFO_RG,c);
  WAIT_CMDR_READY;
  TE6X_set_usart_rg(TE_USART_CH_B+TE_USART_CMDR_RG,0x8);
}


int uart_receive_char()
{ int c;

  while (!(TE6X_usart_rg(TE_USART_CH_B+TE_USART_STAR_RG) &0x20));
  c= TE6X_usart_rg(TE_USART_CH_B+TE_USART_RFIFO_RG) & 0xff;
  WAIT_CMDR_READY;
  TE6X_set_usart_rg(TE_USART_CH_B+TE_USART_CMDR_RG,0x80);	// release RFIFO
  return(c);
}


int uart_receiver_status()
{
  return((TE6X_usart_rg(TE_USART_CH_B+TE_USART_STAR_RG) & 0x20) ? 1:0);
}


uart_transmit_mess(s)
char *s;
{
  while((*s &0xff)!=0) uart_transmit_char(*(s++));
}





void main()
{
	// configure DSP EMIF
	TE6X_init_dsp_emif(TE6X_XMEM_SBSRAM);

	// configure USART
	usart_b_init();

        uart_transmit_mess(welcome);


        while (1)
	 {
	   if(uart_receiver_status()==ML_ON)
              uart_transmit_char(uart_receive_char());
	 }

}
