/********************************************************************
   TORNADO-E64x Demo Utility.
   USB controller test. rev.1A
   (C) MicroLAB Systems, 2000


   Description:
   ------------
	This demo scans registers of USB controller, address lines,
	and generates USB interrupts.


   TORNADO platform:
   -----------------
	This demo does not utilize any host TORNADO resources
	and runs in stand-alone mode. MIRAGE JTAG emulator and
	TI CCS tools are required to recompile this demo and to
	upload code to the on-board DSP environment.

  Copyright:
  ----------
	This demo is distributed free of charge and as it is without
	any obligation from MicroLAB Systems.


  board configuration and demo parameters:
  ----------------------------------------
	- on-board BOOTMODE configuration switch: NOBOOT
***********************************************************************/

#define	__TE6X_SDRAM128M__
#define	__TE6X_SELECT_E64XX__

#include "c6x_def.h"
#include "te6x_dsp.h"


// USB write-to-read pause, which is required for
// operations as WRITE to SCR register, which initializes
// internal state machine operations and requires some
// time to execute
// E64x DSP is very fast and immediate reads may return
// incorrect results.
wait()
{ int i;
   for (i=0;i<60;i++);
}



main()
{ int i, pass;
  unsigned d;

   TE6X_init_dsp_emif(0);

   pass=0;
   while(1)
    {
		TE6X_wdt_reset();

		//-- check USB data bus via running 1<< to the SBIE reg
        for(i=0,d=1;i<=8;i++)
		 {
           TE6X_set_usb_rg(TE_USB_SBIE_RG, i==0 ? 0:d);	
           TE6X_set_usb_rg(TE_USB_SBIE1_RG, 0xff);	// perform false bus data

           if(TE6X_usb_rg(TE_USB_SBIE_RG) != (i==0 ? 0:d))
			goto error;	

           if(i>0)	d <<= 1;
		 }


			//--- perform software reset of USB controller
			//    and verify the results of reset
           TE6X_set_usb_rg(TE_USB_SCR_RG, 0x8);	
		   wait();
           TE6X_set_usb_rg(TE_USB_SCR_RG, 0);	
		   wait();
           if(   TE6X_get_usb_rg(TE_USB_TXCNTH_RG)!=0
	      	  || TE6X_get_usb_rg(TE_USB_TXCNTL_RG)!=0
              || TE6X_get_usb_rg(TE_USB_SBIE_RG)!=0	
              || TE6X_get_usb_rg(TE_USB_SBIE1_RG)!=0	
              || TE6X_get_usb_rg(TE_USB_SCR_RG)!=0
             ) 
			break;	


			//--- now toggle USB interrupt line using INT polarity bit
           TE6X_set_usb_rg(TE_USB_SCR_RG, 0x80);	
		   wait();
           if(TE6X_get_usb_rg(TE_USB_SCR_RG)!=0x80) break;	
           TE6X_set_usb_rg(TE_USB_SCR_RG, 0x00);	
		   wait();
           if(TE6X_get_usb_rg(TE_USB_SCR_RG)!=0x00) break;	


         	//--- now write random data to different USB registers
           TE6X_set_usb_rg(TE_USB_TXCNTH_RG, 0);
           TE6X_set_usb_rg(TE_USB_TXCNTL_RG, 0x91);	
           TE6X_set_usb_rg(TE_USB_SBIE_RG, 0x5a);	
           TE6X_set_usb_rg(TE_USB_SBIE1_RG, 0xa5);	
           TE6X_set_usb_rg(TE_USB_FADDR_RG, 0x47);	
           TE6X_set_usb_rg(TE_USB_SCRATCH_RG, 0x6e);	
           TE6X_set_usb_rg(TE_USB_SCR_RG, 0x92);	

           if( (pass%2) ==0)
		   TE6X_set_usb_rg(TE_USB_MCSR_RG, 0x0);
		     else  TE6X_set_usb_rg(TE_USB_MCSR_RG, 0x1);


           if(TE6X_get_usb_rg(TE_USB_TXCNTL_RG)!=0x91) break;	
           if(TE6X_get_usb_rg(TE_USB_SBIE_RG)!=0x5a) break;	
           if(TE6X_get_usb_rg(TE_USB_SBIE1_RG)!=0xa5) break;	
           if(TE6X_get_usb_rg(TE_USB_FADDR_RG)!=0x47) break;	
           if(TE6X_get_usb_rg(TE_USB_SCRATCH_RG)!=0x6e) break;	
           if(TE6X_get_usb_rg(TE_USB_SCR_RG)!=0x92) break;	


           pass++;
		   if(pass>1000) pass=0;
    }


  error:
    while(1) ;

}



