/********************************************************************
   TORNADO-E64x Demo Utility. USART PIO Test. rev.1A
   (C) MicroLAB Systems, 2000-2002


   Description:
   ------------
	This demo continuously runs '1' thru 8-bit USART parallel I/O port, 
	which is available via JP10 on-board connector and thru 10-bit DSP GPIO, 
	which is available via JP20	connector of TORNADO-E64xx board.


   TORNADO platform:
   -----------------
	This demo does not utilize any host TORNADO resources
	and runs in stand-alone mode. MIRAGE JTAG emulator and
	TI CCS tools are required to recompile this demo and to
	upload code to the on-board DSP environment.

  Copyright:
  ----------
	This demo is distributed free of charge and as it is without
	any obligation from MicroLAB Systems.


  board configuration and demo parameters:
  ----------------------------------------
	- on-board BOOTMODE configuration switch: NOBOOT
*****************************************************/
#define	__TE6X_SDRAM128M__
#define	__TE6X_SELECT_E64XX__


#define	ML_OFF			0
#define	ML_ON			1

#include	<math.h>
#include 	"c6x_def.h"
#include 	"te6x_dsp.h"


void main()
{
	int i,d;

	// configure DSP EMIF
	TE6X_init_dsp_emif(0);

	//configure USART I/O pins as outputs and clear output data
	TE6X_set_usart_rg(TE_USART_PCR_RG,0);  
   	TE6X_set_usart_rg(TE_USART_PVR_RG, 0);

	// configure C64xx DSP GPIO as outputs and clear output data
	// Note, that only GPIO-0/3 and GPIO-8..15 can be used as GPIO pins. 
	// Other are reserved.
	C6X_SET_GPIO_ENABLE_RG(0xff09);
	C6X_SET_GPIO_DIR_RG(0xff09);
	C6X_SET_GPIO_DATA_RG(0);

	while(1)
	 {
		// issue WDT reset for external oscilloscope synchronization
	   	TE6X_wdt_reset();

		// first, run '1' thru USART PIO-0..7 pins 
	   	for(i=0,d=1;i<=8;i++, d<<=1)
	     	TE6X_set_usart_rg(TE_USART_PVR_RG, d);

		// now run '1' thru DSP GPIO pins
		// (for simplicity, '1' is run thru all GPIO-0..15 pins, however it will
		//  appear at the output of only those pins, which are enabled as GPIO.
	   	for(i=0,d=1;i<=16;i++, d<<=1)
			C6X_SET_GPIO_DATA_RG(d);
	 }
}
