/********************************************************************
   TORNADO-E64x Demo Utility.
   RTC (real-time clock) controller CLOCK READ test. rev.1A
   (C) MicroLAB Systems, 2000


   Description:
   ------------
	This reads and verifies RTC clock registers. This test must 
	be used only after RTC CLOCK WRITE test has been run successfully,
	which should have initialized RTC and written RTC clock registers.

	User can switch off the power of TE64xx board after running 
	RTC CLOCK WRITE test and before running RTC CLOCK READ test.

	Note, that this test does not test operation of RTC ALARM and WDT features,
	which are tested in the E64XX_UUR_IRQ.C test in the E6x INTERRUPT test 
	folder.

   TORNADO platform:
   -----------------
	This demo does not utilize any host TORNADO resources
	and runs in stand-alone mode. MIRAGE JTAG emulator and
	TI CCS tools are required to recompile this demo and to
	upload code to the on-board DSP environment.

  Copyright:
  ----------
	This demo is distributed free of charge and as it is without
	any obligation from MicroLAB Systems.


  board configuration and demo parameters:
  ----------------------------------------
	- on-board BOOTMODE configuration switch: NOBOOT
***********************************************************************/

#define	__TE6X_SDRAM128M__
#define	__TE6X_SELECT_E64XX__

#include "c6x_def.h"
#include "te6x_dsp.h"


main()
{ 
	// initialize DSP EMIF
   	TE6X_init_dsp_emif(0);

	// enable access to RTC controller
	TE6X_SET_RTC_ACCESS_ENABLE_ON;
	if(!TE6X_RTC_ACCESS_ENABLE_IS_ON)
	{
		// trap here on error at enable access to RTC controller
		while(1);
	}


	// ensure that TE bit of COMMAND register is ON and RTC clock registers are 
	// unfreezed
	if((TE6X_get_rtc_rg(TE_RTC_CMND_RG) & 0xfc)!=0x80)
	{
		// trap here on COMMAND register read error
		while(1);
	}


	// ensure that clock oscillator (EOSC=0) is running
	if((TE6X_get_rtc_rg(TE_RTC_CLK_MONTH_RG) & 0x80)!=0x00)
	{
		// trap here if oscillator is disabled
		while(1);
	}



	// verify test pattern in RTC USER RAM in order to ensure that
	// RTC CLOCK WRITE tested has been run successfully
	if(		TE6X_get_rtc_user_ram(0x00)!=0x00
		||	TE6X_get_rtc_user_ram(0x01)!=0x11
		||	TE6X_get_rtc_user_ram(0x02)!=0x22
		||	TE6X_get_rtc_user_ram(0x03)!=0x33
		||	TE6X_get_rtc_user_ram(0x04)!=0x44
		||	TE6X_get_rtc_user_ram(0x05)!=0x55
		||	TE6X_get_rtc_user_ram(0x06)!=0x66
		||	TE6X_get_rtc_user_ram(0x07)!=0x77
		||	TE6X_get_rtc_user_ram(0x08)!=0x88
		||	TE6X_get_rtc_user_ram(0x09)!=0x99
		||	TE6X_get_rtc_user_ram(0x0a)!=0xaa
		||	TE6X_get_rtc_user_ram(0x0b)!=0xbb
		||	TE6X_get_rtc_user_ram(0x0c)!=0xcc
		||	TE6X_get_rtc_user_ram(0x0d)!=0xdd
		||	TE6X_get_rtc_user_ram(0x0e)!=0xee
		||	TE6X_get_rtc_user_ram(0x0f)!=0xff
		||	TE6X_get_rtc_user_ram(0x10)!=0x5a
		||	TE6X_get_rtc_user_ram(0x20)!=0xa5
		||	TE6X_get_rtc_user_ram(0x30)!=0x96
		||	TE6X_get_rtc_user_ram(0x31)!=0x69
	  )
	{
		// trap here on RTC USER RAM registers pattern error
		while(1);
	}


	// reset TE bit of COMMAND register and freeze RTC clock registers
	// enable ALARM and WDT output interrupts
	TE6X_set_rtc_rg(TE_RTC_CMND_RG,0x00);
	if((TE6X_get_rtc_rg(TE_RTC_CMND_RG) & 0xfc)!=0x00)
	{
		// trap here on COMMAND register write error
		while(1);
	}


	// now read and verify RTC clock registers and ensure that readen
	// time/date/year is larger than that was written by the RTC CLOCK WRITE
	// test utility

		// first, verify the year YEAR register ('2002)
		// proceed to further verification only in case readen data matches written data	
	if(TE6X_get_rtc_rg(TE_RTC_CLK_YEAR_RG)<0x02)
		goto clock_error;

	if(TE6X_get_rtc_rg(TE_RTC_CLK_YEAR_RG)>0x02)
		goto clock_ok;


		// now verify the month register (MARCH)
		// proceed to further verification only in case readen data matches written data	
	if((TE6X_get_rtc_rg(TE_RTC_CLK_MONTH_RG)&0x1f) <0x03)
		goto clock_error;

	if((TE6X_get_rtc_rg(TE_RTC_CLK_MONTH_RG)&0x1f) >0x03)
		goto clock_ok;
	

		// now verify the date register (14-th)
		// proceed to further verification only in case readen data matches written data	
	if(TE6X_get_rtc_rg(TE_RTC_CLK_DATE_RG)<0x14)
		goto clock_error;

	if(TE6X_get_rtc_rg(TE_RTC_CLK_DATE_RG)>0x14)
		goto clock_ok;
	

		// now verify the day of week register (4-th)
		// proceed to further verification only in case readen data matches written data	
	if(TE6X_get_rtc_rg(TE_RTC_CLK_DAY_OF_WEEK_RG)<0x04)
		goto clock_error;

	if(TE6X_get_rtc_rg(TE_RTC_CLK_DAY_OF_WEEK_RG)>0x04)
		goto clock_ok;
	

		// now verify the hour register (21)
		// proceed to further verification only in case readen data matches written data	
	if(TE6X_get_rtc_rg(TE_RTC_CLK_HOURS_RG)<0x21)
		goto clock_error;

	if(TE6X_get_rtc_rg(TE_RTC_CLK_HOURS_RG)>0x21)
		goto clock_ok;
	

		// now verify the minutes register (10)
		// proceed to further verification only in case readen data matches written data	
	if(TE6X_get_rtc_rg(TE_RTC_CLK_MINUTES_RG)<0x10)
		goto clock_error;

	if(TE6X_get_rtc_rg(TE_RTC_CLK_MINUTES_RG)>0x10)
		goto clock_ok;
	

		// now verify the seconds register (15)
		// proceed to further verification only in case readen data matches written data	
	if(TE6X_get_rtc_rg(TE_RTC_CLK_SECONDS_RG)<0x21)
		goto clock_error;

	if(TE6X_get_rtc_rg(TE_RTC_CLK_SECONDS_RG)>0x15)
		goto clock_ok;
	

clock_does_not_run:
	// Get here on full identity of written and readen time including year/month/date/day/hour/minutes/seconds.
	// Assuming that one second at least should pass after running RTC CLOCK WRITE test,
	// then this actually means that clock did not run due to unknown reasons and
	// can be interpreted as unsuccessfull RTC clock test.

	// disable access to RTC controller
	TE6X_SET_RTC_ACCESS_ENABLE_OFF;
	while(1);


clock_ok:
	// trap here on successfull test run
	// set TE bit of COMMAND register and unfreeze RTC clock registers
	// enable ALARM and WDT output interrupts
	TE6X_set_rtc_rg(TE_RTC_CMND_RG,0x80);

	// finally, disable access to RTC controller
	TE6X_SET_RTC_ACCESS_ENABLE_OFF;
	if(!TE6X_RTC_ACCESS_ENABLE_IS_OFF)
	{
		// trap here on error at disabling RTC access
		while(1);
	}
	while(1);


clock_error:
	// trap here on incorrect clock register data
	// (readen CLOCK registers show earlier time than that written by the RTC CLOCK WRITE test)

	// disable access to RTC controller
	TE6X_SET_RTC_ACCESS_ENABLE_OFF;
	while(1);
}



