/********************************************************************
   TORNADO-E64x Demo Utility.
   RTC (real-time clock) controller CLOCK WRITE test. rev.1A
   (C) MicroLAB Systems, 2000


   Description:
   ------------
	This demo initializes RTC and writes clock registers. This test must 
	be used in conjunction with further run of the RTC CLOCK READ test,
	which will read back and verify RTC clock data and ensure that clock is
	running. User can switch off the power of TE64xx board after running 
	RTC CLOCK WRITE test and before running RTC CLOCK READ test.

	Note, that this test does not test operation of RTC ALARM and WDT features,
	which are tested in the E64XX_UUR_IRQ.C test in the E6x INTERRUPT test 
	folder.

   TORNADO platform:
   -----------------
	This demo does not utilize any host TORNADO resources
	and runs in stand-alone mode. MIRAGE JTAG emulator and
	TI CCS tools are required to recompile this demo and to
	upload code to the on-board DSP environment.

  Copyright:
  ----------
	This demo is distributed free of charge and as it is without
	any obligation from MicroLAB Systems.


  board configuration and demo parameters:
  ----------------------------------------
	- on-board BOOTMODE configuration switch: NOBOOT
***********************************************************************/

#define	__TE6X_SDRAM128M__
#define	__TE6X_SELECT_E64XX__

#include "c6x_def.h"
#include "te6x_dsp.h"


main()
{ 
	// initialize DSP EMIF
   	TE6X_init_dsp_emif(0);

	// enable access to RTC controller
	TE6X_SET_RTC_ACCESS_ENABLE_ON;
	if(!TE6X_RTC_ACCESS_ENABLE_IS_ON)
	{
		// trap here on error at enable access to RTC controller
		while(1);
	}


	//-- initialize RTC clock registers

		// clear TE bit of COMMAND register and freeze RTC clock registers
		// enable ALARM and WDT output interrupts
	TE6X_set_rtc_rg(TE_RTC_CMND_RG,0x00);
	if((TE6X_get_rtc_rg(TE_RTC_CMND_RG) & 0xfc)!=0x00)
	{
		// trap here on COMMAND register write error
		while(1);
	}


		// set fraction of seconds register
	TE6X_set_rtc_rg(TE_RTC_CLK_SECONDS_FRACTION_RG,0x00);
	if(TE6X_get_rtc_rg(TE_RTC_CLK_SECONDS_FRACTION_RG)!=0x00)
	{
		// trap here on SECONDS FRACTION register write error
		while(1);
	}


		// set seconds register
	TE6X_set_rtc_rg(TE_RTC_CLK_SECONDS_RG,0x15);
	if(TE6X_get_rtc_rg(TE_RTC_CLK_SECONDS_RG)!=0x15)
	{
		// trap here on SECONDS register write error
		while(1);
	}


		// set minutes register (10min)
	TE6X_set_rtc_rg(TE_RTC_CLK_MINUTES_RG,0x10);
	if(TE6X_get_rtc_rg(TE_RTC_CLK_MINUTES_RG)!=0x10)
	{
		// trap here on MINUTES register write error
		while(1);
	}


		// set hours register (21 hour)
	TE6X_set_rtc_rg(TE_RTC_CLK_HOURS_RG,0x21);
	if(TE6X_get_rtc_rg(TE_RTC_CLK_HOURS_RG)!=0x21)
	{
		// trap here on HOURS register write error
		while(1);
	}


		// set day of week register (=4 (THURSDAY))
	TE6X_set_rtc_rg(TE_RTC_CLK_DAY_OF_WEEK_RG,0x04);
	if(TE6X_get_rtc_rg(TE_RTC_CLK_DAY_OF_WEEK_RG)!=0x04)
	{
		// trap here on DAY OF WEEK register write error
		while(1);
	}


		// set date register (14-th)
	TE6X_set_rtc_rg(TE_RTC_CLK_DATE_RG,0x14);
	if(TE6X_get_rtc_rg(TE_RTC_CLK_DATE_RG)!=0x14)
	{
		// trap here on DATE register write error
		while(1);
	}


		// enable clock oscillator (EOSC=0) and set MONTH=MARCH
	TE6X_set_rtc_rg(TE_RTC_CLK_MONTH_RG,0x03);
	if(TE6X_get_rtc_rg(TE_RTC_CLK_MONTH_RG)!=0x03)
	{
		// trap here on MONTH/EOSC register write error
		while(1);
	}



		// set YEAR register ('2002)
	TE6X_set_rtc_rg(TE_RTC_CLK_YEAR_RG,0x02);
	if(TE6X_get_rtc_rg(TE_RTC_CLK_YEAR_RG)!=0x02)
	{
		// trap here on YEAR register write error
		while(1);
	}



		// clear ALARM registers
	TE6X_set_rtc_rg(TE_RTC_ALARM_MINUTES_RG,0x00);
	TE6X_set_rtc_rg(TE_RTC_ALARM_HOURS_RG,0x00);
	TE6X_set_rtc_rg(TE_RTC_ALARM_DAY_OF_WEEK_RG,0x00);
	if(		TE6X_get_rtc_rg(TE_RTC_ALARM_MINUTES_RG)!=0x00
		||	TE6X_get_rtc_rg(TE_RTC_ALARM_HOURS_RG)!=0x00
		||	TE6X_get_rtc_rg(TE_RTC_ALARM_DAY_OF_WEEK_RG)!=0x00
	  )
	{
		// trap here on ALARM registers write error
		while(1);
	}


		// clear WDT registers
	TE6X_set_rtc_rg(TE_RTC_WDT_SECONDS_FRACTION_RG,0x00);
	TE6X_set_rtc_rg(TE_RTC_WDT_SECONDS_RG,0x00);
	if(		TE6X_get_rtc_rg(TE_RTC_WDT_SECONDS_FRACTION_RG)!=0x00
		||	TE6X_get_rtc_rg(TE_RTC_WDT_SECONDS_RG)!=0x00
	  )
	{
		// trap here on WDT registers write error
		while(1);
	}



		// now write test pattern to RTC USER RAM in order further running
		// RTC CLOCK READ test could verify that CLOCK written data
		// are valid
	TE6X_set_rtc_user_ram(0x00,0x00);	
	TE6X_set_rtc_user_ram(0x01,0x11);	
	TE6X_set_rtc_user_ram(0x02,0x22);	
	TE6X_set_rtc_user_ram(0x03,0x33);	
	TE6X_set_rtc_user_ram(0x04,0x44);	
	TE6X_set_rtc_user_ram(0x05,0x55);	
	TE6X_set_rtc_user_ram(0x06,0x66);	
	TE6X_set_rtc_user_ram(0x07,0x77);	
	TE6X_set_rtc_user_ram(0x08,0x88);	
	TE6X_set_rtc_user_ram(0x09,0x99);	
	TE6X_set_rtc_user_ram(0x0a,0xaa);	
	TE6X_set_rtc_user_ram(0x0b,0xbb);	
	TE6X_set_rtc_user_ram(0x0c,0xcc);	
	TE6X_set_rtc_user_ram(0x0d,0xdd);	
	TE6X_set_rtc_user_ram(0x0e,0xee);	
	TE6X_set_rtc_user_ram(0x0f,0xff);	
	TE6X_set_rtc_user_ram(0x10,0x5a);	
	TE6X_set_rtc_user_ram(0x20,0xa5);	
	TE6X_set_rtc_user_ram(0x30,0x96);	
	TE6X_set_rtc_user_ram(0x31,0x69);	

	
	if(		TE6X_get_rtc_user_ram(0x00)!=0x00
		||	TE6X_get_rtc_user_ram(0x01)!=0x11
		||	TE6X_get_rtc_user_ram(0x02)!=0x22
		||	TE6X_get_rtc_user_ram(0x03)!=0x33
		||	TE6X_get_rtc_user_ram(0x04)!=0x44
		||	TE6X_get_rtc_user_ram(0x05)!=0x55
		||	TE6X_get_rtc_user_ram(0x06)!=0x66
		||	TE6X_get_rtc_user_ram(0x07)!=0x77
		||	TE6X_get_rtc_user_ram(0x08)!=0x88
		||	TE6X_get_rtc_user_ram(0x09)!=0x99
		||	TE6X_get_rtc_user_ram(0x0a)!=0xaa
		||	TE6X_get_rtc_user_ram(0x0b)!=0xbb
		||	TE6X_get_rtc_user_ram(0x0c)!=0xcc
		||	TE6X_get_rtc_user_ram(0x0d)!=0xdd
		||	TE6X_get_rtc_user_ram(0x0e)!=0xee
		||	TE6X_get_rtc_user_ram(0x0f)!=0xff
		||	TE6X_get_rtc_user_ram(0x10)!=0x5a
		||	TE6X_get_rtc_user_ram(0x20)!=0xa5
		||	TE6X_get_rtc_user_ram(0x30)!=0x96
		||	TE6X_get_rtc_user_ram(0x31)!=0x69
	  )
	{
		// trap here on RTC USER RAM registers pattern write error
		while(1);
	}


		// set TE bit of COMMAND register and unfreeze RTC clock registers
	TE6X_set_rtc_rg(TE_RTC_CMND_RG,0x80);
	if((TE6X_get_rtc_rg(TE_RTC_CMND_RG) & 0xfc)!=0x80)
	{
		// trap here on COMMAND register write error
		while(1);
	}


	// finally, disable access to RTC controller
	TE6X_SET_RTC_ACCESS_ENABLE_OFF;
	if(!TE6X_RTC_ACCESS_ENABLE_IS_OFF)
	{
		// trap here on error at disabling RTC access
		while(1);
	}


	// get here on successfull program execution
	while(1);
}



